==> itplugin-0.0.1.tar.gz: lib/controls/it_flat_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class ItFlatButton extends StatefulWidget {
  final String text;
  final Color color;
  final double borderRadius;
  final double height;
  final double maxWidth;
  final Function onClick;
  final TextStyle textStyle;
  final GlobalKey<FormState> formKey;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  ItFlatButton(this.text,
      {Key key,
      this.margin,
      this.height,
      this.color,
      this.padding,
      this.onClick,
      this.textStyle,
      this.maxWidth = 100,
      this.borderRadius = 10,
      this.formKey})
      : super(key: key);

  @override
  _ItFlatButtonState createState() => _ItFlatButtonState();
}

class _ItFlatButtonState extends State<ItFlatButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      margin: widget.margin,
      padding: widget.padding,
      height: widget.height,
      child: FlatButton(
        onPressed: widget.onClick,
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(widget.borderRadius)),
        padding: EdgeInsets.all(0.0),
        child: Ink(
          decoration: BoxDecoration(
            color: widget.color,
              borderRadius: BorderRadius.circular(widget.borderRadius)),
          child: Container(
            constraints:
                BoxConstraints(maxWidth: widget.maxWidth, minHeight: 50.0),
            alignment: Alignment.center,
            child: Text(
              widget.text,
              textAlign: TextAlign.center,
              style: widget.textStyle,
            ),
          ),
        ),
      ),
    );
  }
}

==> itplugin-0.0.6.tar.gz: lib/controls/it_flat_button.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class ItFlatButton extends StatefulWidget {
  final String text;
  final Color color;
  final double borderRadius;
  final double height;
  final double width;
  final Function onClick;
  final TextStyle textStyle;
  final GlobalKey<FormState> formKey;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  ItFlatButton(this.text,
      {Key key,
      this.margin,
      this.height,
      this.color,
      this.padding,
      this.onClick,
      this.textStyle,
      this.width = 100,
      this.borderRadius = 10,
      this.formKey})
      : super(key: key);

  @override
  _ItFlatButtonState createState() => _ItFlatButtonState();
}

class _ItFlatButtonState extends State<ItFlatButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      margin: widget.margin,
      padding: widget.padding,
      height: widget.height,
      width: widget.width,
      child: FlatButton(
        onPressed: widget.onClick,
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(widget.borderRadius)),
        padding: EdgeInsets.all(0.0),
        child: Ink(
          decoration: BoxDecoration(
              color: widget.color,
              borderRadius: BorderRadius.circular(widget.borderRadius)),
          child: Container(
            constraints:
                BoxConstraints(maxWidth: widget.width, minHeight: 50.0),
            alignment: Alignment.center,
            child: Text(
              widget.text,
              textAlign: TextAlign.center,
              style: widget.textStyle,
            ),
          ),
        ),
      ),
    );
  }
}
